@@ -11,7 +11,7 @@ import abobjs
 class AB_Workspace(abobjs.AB_Base):
 
     _endpoint = "/api/v1/workspaces"
-    _single = ".worksapces[0]"
+    _single = ".workspaces[0]"
     _name = "workspace"
     #_datefront = "%Y-%m-%dT%H:%M:%S"
     #_mslength = 3
@@ -19,6 +19,7 @@ class AB_Workspace(abobjs.AB_Base):
 	#              "baseline_date", "last_modification_date", "last_review_date"]
 
     #_strips = ["_permissions"]
+    _uid_field = None
 
     def __init__(self, id=None, api_info=None, **kwargs):
 
